@@ -315,7 +315,7 @@ class BarProvider:
                         return 2
                     return 0
 
-            if (current_date_time_slice.begin_time <= begin_time) & (end_time < next_date_time_slice.begin_time):
+            if (current_date_time_slice.begin_time <= begin_time) & (begin_time < next_date_time_slice.begin_time):
                 return 0
         else:
             # 收盘5秒内的tick都计算
