@@ -356,9 +356,104 @@ class QiDataController:
 
         return bar_provider.bar_series
 
-    def load_bar_series_by_length(self, market, instrument_id, interval, bar_type, max_length, end_time, *instrument_ids):
+    def load_bar_series_by_length(self, market, instrument_id, interval, bar_type, max_length, end_date, *instrument_ids):
         """
+        根据结束日期加载指定回溯根数的历史K线（K线数据包含结束日期）
+        :param market:
+        :param instrument_id:
+        :param interval:
+        :param bar_type:
+        :param max_length:
+        :param end_date:
+        :param instrument_ids:
+        :return:
+        """
+        # 这里为了提升取数据的速度,根据时间预计算根数,不足再补
+        end_trading_date = TradingDayHelper.get_last_trading_day(end_date)
+        lst_date_time_slices_one_day = BaseBarHelper.create_one_day_date_time_slice(
+            self.instrument_manager, instrument_id, end_trading_date, interval, bar_type, *instrument_ids)
+        if len(lst_date_time_slices_one_day) > 0:
+            n_one_day_count = len(lst_date_time_slices_one_day)
+        else:
+            n_one_day_count = 1
 
+        n_trading_days = int(math.ceil(max_length * 1.0 / n_one_day_count))
+        if bar_type == EnumBarType.day:
+            n_trading_days = n_trading_days * interval
+        else:
+            n_trading_days = n_trading_days
+
+        begin_trading_date = TradingDayHelper.get_pre_trading_day(end_trading_date, n_trading_days - 1)
+        lst_trading_days = TradingDayHelper.get_trading_days(begin_trading_date, end_trading_date)
+        bar_provider = BarProvider()
+        bar_provider.create_bar_provider_by_date(
+            self.instrument_manager, instrument_id, begin_trading_date, end_trading_date, interval, bar_type, *instrument_ids)
+        if bar_provider.bar_type == EnumBarType.second:
+            for trading_day in lst_trading_days:
+                tick_series = self.__load_history_tick_series(market, instrument_id, trading_day)
+                for tick in tick_series:
+                    bar_provider.add_tick(tick)
+        elif (bar_provider.bar_type == EnumBarType.minute) | (bar_provider.bar_type == EnumBarType.hour):
+            bar_series_min = self.load_min_bar_series(market, instrument_id, begin_trading_date, end_trading_date)
+            for bar in bar_series_min:
+                bar_provider.add_bar(bar)
+        elif bar_provider.bar_type == EnumBarType.day:
+            bar_series_day = self.load_day_bar_series(market, instrument_id, begin_trading_date, end_trading_date)
+            for bar in bar_series_day:
+                bar_provider.add_bar(bar)
+        else:
+            raise Exception("不支持的k线:" + str(bar_type))
+
+        bar_series = bar_provider.bar_series
+        if len(bar_provider.bar_series) < max_length:
+            trading_date = begin_trading_date
+            count = 0
+            while count < 5:
+                count += 1
+                trading_date = TradingDayHelper.get_pre_trading_day(trading_date)
+                if bar_provider.bar_type == EnumBarType.second:
+                    bar_provider = BarProvider()
+                    bar_provider.create_bar_provider_by_trading_date(self.instrument_manager, instrument_id, trading_date, interval, bar_type, *instrument_ids)
+                    tick_series = self.__load_history_tick_series(market, instrument_id, trading_date)
+                    for tick in tick_series:
+                        bar_provider.add_tick(tick)
+                elif (bar_provider.bar_type == EnumBarType.minute) | (bar_provider.bar_type == EnumBarType.hour):
+                    bar_provider = BarProvider()
+                    bar_provider.create_bar_provider_by_trading_date(self.instrument_manager, instrument_id, trading_date, interval, bar_type, *instrument_ids)
+                    bar_series_min = self.load_min_bar_series(market, instrument_id, trading_date)
+                    for bar in bar_series_min:
+                        bar_provider.add_bar(bar)
+                elif bar_provider.bar_type == EnumBarType.day:
+                    begin_date = TradingDayHelper.get_pre_trading_day(trading_date, interval - 1)
+                    bar_provider = BarProvider()
+                    bar_provider.create_bar_provider_by_trading_date(self.instrument_manager, instrument_id, trading_date, interval, bar_type, *instrument_ids)
+                    bar_series_day = self.load_day_bar_series(market, instrument_id, begin_date, end_trading_date)
+                    trading_date = begin_date
+                    for bar in bar_series_day:
+                        bar_provider.add_bar(bar)
+                else:
+                    raise Exception("不支持的k线:" + str(bar_type))
+
+                for bar in bar_provider.bar_series:
+                    bar_series.insert(0, bar)
+
+                if len(bar_series) >= max_length:
+                    break
+
+        bar_provider = BarProvider()
+        bar_provider.create_bar_provider_by_trading_date(self.instrument_manager, instrument_id, self.trading_day, interval, bar_type, *instrument_ids)
+        for bar in bar_series:
+            bar_provider.bar_series.append(bar)
+
+        remove_length = len(bar_provider.bar_series) - max_length
+        if remove_length > 0:
+            del bar_provider.bar_series[0:remove_length]
+
+        return bar_provider.bar_series
+
+    def load_bar_series_by_length_by_date_time(self, market, instrument_id, interval, bar_type, max_length, end_time, *instrument_ids):
+        """
+        根据结束时间加载指定回溯根数的历史K线（K线数据都小于等于结束时间）
         :param market:
         :param instrument_id:
         :param interval:
@@ -638,7 +733,8 @@ class QiDataController:
             end_trading_date = TradingDayHelper.get_pre_trading_day(last_trading_day)
         else:
             end_trading_date = last_trading_day
-        lst_date_time_slices_one_day = BaseBarHelper.create_one_day_date_time_slice(self.instrument_manager, instrument_id, end_trading_date, interval, bar_type,
+        lst_date_time_slices_one_day = BaseBarHelper.create_one_day_date_time_slice(self.instrument_manager, instrument_id, end_trading_date, interval,
+                                                                                    bar_type,
                                                                                     *instrument_ids)
         if len(lst_date_time_slices_one_day) > 0:
             n_one_day_count = len(lst_date_time_slices_one_day)
