@@ -45,11 +45,11 @@ end_time = datetime.datetime(trading_day.year, trading_day.month, trading_day.da
 #     index += 1
 
 
-# begin_trading_date = datetime.datetime(2017, 7, 4)
+# begin_trading_date = datetime.datetime(2017, 7, 5)
 # end_trading_date = datetime.datetime(2017, 7, 5)
 # instrument_id = "rb9999"
 # interval = 1
-# bar_type = EnumBarType.minute
+# bar_type = EnumBarType.hour
 # bar_series = qi_data_controller.load_bar_series_by_date(EnumMarket.期货, instrument_id, interval, bar_type, begin_trading_date, end_trading_date)
 # index = 1
 # for bar in bar_series:
@@ -71,7 +71,7 @@ length = 20
 end_trading_date = datetime.datetime(2019, 5, 7)
 instrument_id = "ag9999"
 interval = 1
-bar_type = EnumBarType.day
+bar_type = EnumBarType.hour
 bar_series = qi_data_controller.load_bar_series_by_length(EnumMarket.期货, instrument_id, interval, bar_type, length, end_trading_date)
 index = 1
 for bar in bar_series:
